@@ -35,30 +35,22 @@ class Login(Command):
 
         state, args = self.apply_state(args, state)
 
-        args, print_token = Command.extract_options(args, '--print-token')
-
         username: str = None
         if len(args) > 0:
             username = args[0]
 
         login: IdpLogin = None
-        while not login:
-            try:
-                if not(host := Apps.app_host('c3', 'c3', state.namespace)):
-                    log2('Cannot locate ingress for app.')
-                    username = None
-                    continue
+        try:
+            if not(host := Apps.app_host('c3', 'c3', state.namespace)):
+                log2('Cannot locate ingress for app.')
+                return state
 
-                uri = Idp.build_uri(host, host)
-                if not (login := Idp.login(host, uri, username=username, use_cached=False)):
-                    log2('Invalid username/password. Please try again.')
-                    username = None
-            except:
-                log2(traceback.format_exc())
-                pass
+            if not (login := Idp.login(host, username=username, use_token_from_env=False)):
+                log2('Invalid username/password. Please try again.')
+        except:
+            log2(traceback.format_exc())
 
-        if print_token:
-            log(f'IDP_TOKEN={login.ser()}')
+        log(f'IDP_TOKEN={login.ser() if login else ""}')
 
         return state
 
