@@ -142,4 +142,4 @@ class Ls(Command):
         return {Ls.COMMAND: None}
 
     def help(self, _: ReplState):
-        return f'{Ls.COMMAND} [device:]\t list clusters|nodes|pg hosts|pg databases'
\ No newline at end of file
+        return f'{Ls.COMMAND} [device:]\t list apps, envs, clusters, nodes, pg hosts or pg databases'
\ No newline at end of file
