@@ -1,5 +1,7 @@
+from walker.app_session import AppSession
 from walker.apps import AppAction, Apps
 from walker.commands.command import Command
+from walker.config import Config
 from walker.repl_state import ReplState
 from walker.utils import lines_to_tabular, log
 
@@ -35,6 +37,12 @@ class ShowAppActions(Command):
                     line = f'{line},{a.help}'
                 lines.append(line)
         log(lines_to_tabular(lines, 'ACTION,ARGS,DESCRIPTION', separator=','))
+        log()
+
+        app_session: AppSession = AppSession.create(state.app_env or 'c3', state.app_app or 'c3')
+        endpoint = Config().get('app.console-endpoint', 'https://{host}/{env}/{app}/static/console/index.html')
+        endpoint = endpoint.replace('{host}', app_session.host).replace('{env}', app_session.env).replace('{app}', state.app_app or 'c3')
+        log(lines_to_tabular([f'CONSOLE:,{endpoint}'], separator=','))
 
         return lines
 
