@@ -2,6 +2,7 @@ import os
 import signal
 import traceback
 
+from walker.config import Config
 from walker.sso.idp import Idp
 from walker.app_session import AppSession, IdpLogin
 from walker.apps import Apps
@@ -47,21 +48,18 @@ class UserEntry(Command):
                     username = None
                     continue
 
-                uri = Idp.build_uri(host, host)
-                if not (login := Idp.login(host, uri, username=username, use_cached=False)):
+                if not (login := Idp.login(host, username=username, use_token_from_env=False)):
                     log2('Invalid username/password. Please try again.')
                     username = None
             except:
-                # log2(traceback.format_exc())
-                pass
+                if Config().is_debug():
+                    log2(traceback.format_exc())
 
         sh = f'{os.getcwd()}/login.sh'
         if not os.path.exists(sh):
             sh = f'{os.getcwd()}/docker/login.sh'
 
-        username = login.user.split('@')[0].replace('.', '')
-
-        os.system(f'{sh} {username} {login.ser()}')
+        os.system(f'{sh} {login.shell_user()} {login.ser()}')
 
         return state
 
