@@ -53,6 +53,9 @@ class Config:
     def keys(self) -> list[str]:
         return get_deep_keys(self.params)
 
+    def is_debug(self):
+        return Config().get('debug.show-out', False)
+
     def get(self, key: str, default: T) -> T:
         # params['nodetool']['status']['max-nodes']
         d = self.params
