@@ -102,7 +102,7 @@ class KubeContext:
         return name if re.match(r"^(?!pg-).*-k8spg-.*$", name) else None
 
     def show_out(s: bool):
-        return s or Config().get('debug.show-out', False)
+        return s or Config().is_debug()
 
     def show_parallelism():
         return Config().get('debug.show-parallelism', False)
\ No newline at end of file
