@@ -1,6 +1,7 @@
 from typing import List
 from kubernetes import client
 
+from walker.config import Config
 from walker.utils import log2
 
 from .kube_context import KubeContext
@@ -25,13 +26,14 @@ class Services:
         else:
             return [f"{svc}" for svc, _ in Services.list_svc_name_and_ns(label_selector=label_selector)]
 
-    def create_service(name: str, namespace: str, port: int, selector: dict):
+    def create_service(name: str, namespace: str, port: int, selector: dict[str, str], labels: dict[str, str] = {}):
         v1 = client.CoreV1Api()
         body = client.V1Service(
             api_version="v1",
             kind="Service",
             metadata=client.V1ObjectMeta(
-                name=name
+                name=name,
+                labels=labels
             ),
             spec=client.V1ServiceSpec(
                 selector=selector,
@@ -45,18 +47,32 @@ class Services:
         # (Can replace "default" with a namespace you may have created)
         v1.create_namespaced_service(namespace=namespace, body=body)
 
-    def delete_service(name: str, namespace: str):
+    def delete_services(namespace: str, services: list[client.V1Service] = None, label_selector = None, dry = False):
+        if services:
+            for service in services:
+                Services.delete_service(service.metadata.name, namespace, dry=dry)
+
+        if label_selector:
+            services = Services.list_services(label_selector)
+            for service in services:
+                Services.delete_service(service.metadata.name, namespace, dry=dry)
+
+    def delete_service(name: str, namespace: str, dry = False):
         try:
             v1 = client.CoreV1Api()
 
             delete_options = client.V1DeleteOptions()
 
-            api_response = v1.delete_namespaced_service(
-                name=name,
-                namespace=namespace,
-                body=delete_options
-            )
-            log2(f"{api_response.status} Service '{name}' in namespace '{namespace}' deleted successfully.")
+            if dry:
+                log2(f"200 Service '{name}' in namespace '{namespace}' deleted successfully.")
+            else:
+                api_response = v1.delete_namespaced_service(
+                    name=name,
+                    namespace=namespace,
+                    body=delete_options
+                )
+                if Config().is_debug():
+                    log2(f"200 Service '{name}' in namespace '{namespace}' deleted successfully.")
         except client.ApiException as e:
             log2(f"Error deleting Service '{name}': {e}")
         except Exception as e:
